# EulerKit

<!-- Badges -->
![GitHub Workflow Status](https://img.shields.io/github/actions/workflow/status/MarcoPlatino/EulerKit/python_publish.yml?branch=main)
[![PyPI Version](https://img.shields.io/pypi/v/eulerkit.svg)](https://pypi.org/project/eulerkit/)
![Python Versions](https://img.shields.io/pypi/pyversions/eulerkit.svg)
![License](https://img.shields.io/github/license/MarcoPlatino/EulerKit)
[![Issues](https://img.shields.io/github/issues/MarcoPlatino/EulerKit.svg)](https://github.com/MarcoPlatino/EulerKit/issues)
[![Pull Requests](https://img.shields.io/github/issues-pr/MarcoPlatino/EulerKit.svg)](https://github.com/MarcoPlatino/EulerKit/pulls)

This is a Python Library inspired by the functions that are needed to solve many Project Euler problems. It also includes some utilities that I personally enjoy very much.

Here is a (non-comprehensive) list of features that are in the library:
- Palindromes 
    - The ability to verify if a number is a palindrome
- Prime Generation
    - The ability to generate a large set of prime numbers - to a list or to a file if you want to pre-generate them.
- Pandigital
    - The ability to verify if a number is pandigital or not

### Quickstart:
You can install the library by running this simple command:

`pip install EulerKit`

From there you can begin using the library immediately by importing it at the top of your python projects like this:

```python
from EulerKit import*
```

If you want a more comprehensive guide, check the [wiki](https://github.com/MarcoPlatino/EulerKit/wiki)

If you are curious, the PyPi page is located [here](https://pypi.org/project/EulerKit/)
